from pathlib import Path
from uuid import UUID
from ragloader.files_indexing import File, Document


class ParsedFile:
    """This class provides an abstraction for a parsed file."""

    def __init__(self,
                 file: File,
                 file_content: str
        ):
        self.file_uuid: UUID = file.uuid
        self.file_path: Path = file.file_path
        self.file_name: str = file.file_name
        self.file_extension: str = file.extension

        self.file_metadata: dict = {}
        self.file_content: str = file_content

    def to_json(self) -> dict:
        """Converts a `ParsedFile` object into a JSON serializable dict"""
        return {
            "uuid": str(self.file_uuid),
            "file_path": str(self.file_path),
            "file_name": self.file_name,
            "file_extension": self.file_extension,
            "file_metadata": self.file_metadata,
        }


class ParsedDocument:
    """This class provides an abstraction for a parsed document."""

    def __init__(self,
                 document: Document):
        self.document_uuid: UUID = document.uuid
        self.document_name: str = document.document_name

        self.document_content: str = ""

        self.parsed_files: list[ParsedFile] = []

    def add_parsed_file(self, parsed_file: ParsedFile):
        """Adds a parsed file to the list of parsed files for a document."""
        self.document_content += ("\n" + parsed_file.file_content)
        self.parsed_files.append(parsed_file)
