from uuid import UUID

from ragloader.documents_classification.classified_items import (
    ParsedDocumentWithContent
)


class DocumentChunk:
    """Class representing a chunk of a document."""

    def __init__(self, content: str, index: int):
        self.content: str = content
        self.chunk_index: int = index
        self.document_metadata: dict = {}

    def add_metadata(self, document_metadata: dict) -> None:
        self.document_metadata: dict = document_metadata


class ChunkedDocument:
    """Class representing a document split into chunks."""

    def __init__(self, parent_document: ParsedDocumentWithContent):
        self.document_uuid: UUID = parent_document.document_uuid
        self.document_content: str = parent_document.document_content
        self.document_class: str = parent_document.document_class
        self.document_schema: dict = parent_document.document_schema
        self.document_name: str = parent_document.document_name
        self.chunks: list[DocumentChunk] = []

    def add_chunk(self, content: str) -> None:
        chunk = DocumentChunk(content, len(self.chunks))
        chunk.add_metadata(
            {
                "document_name": self.document_name,
                "document_class": self.document_class,
                "parent_document_uuid": str(self.document_uuid),
            }
        )
        self.chunks.append(chunk)
